@@ -3,11 +3,14 @@ use warnings;
 package Dist::Zilla::App::Command::stale;
 # ABSTRACT: print your distribution's prerequisites and plugins that are out of date
 # vim: set ts=8 sw=4 tw=78 et :
-our $VERSION = '0.038';
+
+our $VERSION = '0.039';
+
 use Dist::Zilla::App -command;
 use List::Util 1.33 'any';
 use List::MoreUtils 'uniq';
 use Try::Tiny;
+use Config::MVP::Section 2.200004 ();
 use namespace::autoclean;
 
 sub abstract { "print your distribution's stale prerequisites and plugins" }
@@ -78,20 +81,24 @@ sub execute
     catch {
         my @authordeps;
 
-        # if a plugin or bundle tries to loads another module that isn't
-        # installed or at the wrong version, catch it and add to the list of missing modules
-        if (/\ACan't locate (\S+) .+ at \S+ line/
-            or /^Compilation failed in require at (\S+) line/
-            or /^(\S+) version \S+ required--this is only version \S+ at \S+ line/)
+        # a plugin or bundle tried to loads another module that isn't installed
+        if (/^Can't locate (\S+) .+ at \S+ line/
+            or /^Compilation failed in require at (\S+) line/)
         {
-            my $module = $1 || $2 || $3;
+            my $module = $1 || $2;
             $module =~ s{/}{::}g;
             $module =~ s{\.pm$}{};
             push @authordeps, $module;
         }
+        # ...or at the wrong version
+        elsif (/^(\S+) version \S+ required--this is only version \S+ at \S+ line/)
+        {
+            push @authordeps, $1;
+        }
         else
         {
-            push @authordeps, $1 if /Required plugin (\S+) isn't installed\./;
+            # a plugin was referenced in dist.ini or a bundle
+            push @authordeps, $1 if /Required plugin \[?(\S+)\]? isn't installed\./;
 
             # some plugins are not installed; need to run authordeps --missing
             die $_ unless
@@ -150,7 +157,7 @@ Dist::Zilla::App::Command::stale - print your distribution's prerequisites and p
 
 =head1 VERSION
 
-version 0.038
+version 0.039
 
 =head1 SYNOPSIS
 
