@@ -1,17 +1,18 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.037-2-g26d2b30
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.038-12-g8400758
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
 # vim: set ts=8 sw=4 tw=78 et :
-our $VERSION = '0.038';
+
+our $VERSION = '0.039';
+
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
     'Dist::Zilla::Role::AfterBuild',
     'Dist::Zilla::Role::BeforeRelease';
 
 use Moose::Util::TypeConstraints;
-use MooseX::Types::Moose qw(ArrayRef Bool Str);
 use List::Util 1.33 qw(none any);
 use List::MoreUtils 'uniq';
 use version;
@@ -22,7 +23,7 @@ use HTTP::Tiny;
 use YAML::Tiny;
 use Module::Path 0.18 'module_path';
 use Module::Metadata 1.000023;
-use Module::CoreList 3.10;  # includes information about the 5.20.0 release
+use Module::CoreList 5.20150214;
 use Encode ();
 use namespace::autoclean;
 
@@ -39,7 +40,7 @@ has phase => (
 );
 
 has modules => (
-    isa => ArrayRef[Str],
+    isa => 'ArrayRef[Str]',
     traits => [ 'Array' ],
     handles => { _raw_modules => 'elements' },
     lazy => 1,
@@ -47,22 +48,22 @@ has modules => (
 );
 
 has check_authordeps => (
-    is => 'ro', isa => Bool,
+    is => 'ro', isa => 'Bool',
     default => 0,
 );
 
 has check_all_plugins => (
-    is => 'ro', isa => Bool,
+    is => 'ro', isa => 'Bool',
     default => 0,
 );
 
 has check_all_prereqs => (
-    is => 'ro', isa => Bool,
+    is => 'ro', isa => 'Bool',
     default => 0,
 );
 
 has skip => (
-    isa => ArrayRef[Str],
+    isa => 'ArrayRef[Str]',
     traits => [ 'Array' ],
     handles => { skip => 'elements' },
     lazy => 1,
@@ -70,12 +71,12 @@ has skip => (
 );
 
 has fatal => (
-    is => 'ro', isa => Bool,
+    is => 'ro', isa => 'Bool',
     default => 0,
 );
 
 has index_base_url => (
-    is => 'ro', isa => Str,
+    is => 'ro', isa => 'Str',
 );
 
 around dump_config => sub
@@ -447,7 +448,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.038
+version 0.039
 
 =head1 SYNOPSIS
 
